
# Bluetooth Presence Checker
This module checks the presence of a bluetooth mac address and displays:
 - BT device name
 - RSSI value
 - absent/present

## Installation
```
sudo apt-get install bluetooth
sudo apt-get install python-bluez
```

## Usage
```
define my_smartphone PythonModule bt_presence <MAC>
```